#include "config.h"

#if ENABLE_NETSNMP==1
#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>

int number1 = 42;
int accepted = 43;

int
handle_counter32(netsnmp_mib_handler *handler,
                          netsnmp_handler_registration *reginfo,
                          netsnmp_agent_request_info   *reqinfo,
                          netsnmp_request_info         *requests)
{
    /* We are never called for a GETNEXT if it's registered as a
       "instance", as it's "magically" handled for us.  */

    /* a instance handler also only hands us one request at a time, so
       we don't need to loop over a list of requests; we'll only get one. */

int i;
printf("*** name: ");
for (i=0; i<requests->requestvb->name_length; i++) {
  printf("%d ", requests->requestvb->name[i]);
}
printf("\n");
    
    switch(reqinfo->mode) {

        case MODE_GET:
            snmp_set_var_typed_value(requests->requestvb, ASN_COUNTER,
                                     (u_char *) &number1/* XXX: a pointer to the scalar's data */,
                                     sizeof(number1) /* XXX: the length of the data in bytes */);
            break;


        default:
            /* we should never get here, so this is a really bad error */
            return SNMP_ERR_GENERR;
    }

    return SNMP_ERR_NOERROR;
}

int
handle_dhsAccepted(netsnmp_mib_handler *handler,
                          netsnmp_handler_registration *reginfo,
                          netsnmp_agent_request_info   *reqinfo,
                          netsnmp_request_info         *requests)
{
    /* We are never called for a GETNEXT if it's registered as a
       "instance", as it's "magically" handled for us.  */

    /* a instance handler also only hands us one request at a time, so
       we don't need to loop over a list of requests; we'll only get one. */
    
    switch(reqinfo->mode) {

        case MODE_GET:
            snmp_set_var_typed_value(requests->requestvb, ASN_COUNTER,
                                     (u_char *) &accepted/* XXX: a pointer to the scalar's data */,
                                     sizeof(accepted) /* XXX: the length of the data in bytes */);
            break;


        default:
            /* we should never get here, so this is a really bad error */
            return SNMP_ERR_GENERR;
    }

    return SNMP_ERR_NOERROR;
}

/** Initializes the dhsMIBObjects module */
void
init_dhsMIBObjects(void)
{
    static oid dhsNumber1_oid[] = { 1,3,6,1,4,1,9676,2,1,1 };
    static oid dhsAccepted_oid[] = { 1,3,6,1,4,1,9676,2,1,2,1 };


  DEBUGMSGTL(("dhsMIBObjects", "Initializing\n"));

    netsnmp_register_scalar(
        netsnmp_create_handler_registration("dhsNumber1", handle_counter32,
                               dhsNumber1_oid, OID_LENGTH(dhsNumber1_oid),
                               HANDLER_CAN_RONLY
        ));
    netsnmp_register_scalar(
        netsnmp_create_handler_registration("dhsAccepted", handle_counter32,
                               dhsAccepted_oid, OID_LENGTH(dhsAccepted_oid),
                               HANDLER_CAN_RONLY
        ));

}

void snmp_subagent_main () {
  int res;

printf("snmp_subagent_main: 1\n");
  snmp_enable_stderrlog();
printf("snmp_subagent_main: 2\n");
  netsnmp_ds_set_boolean(NETSNMP_DS_APPLICATION_ID, NETSNMP_DS_AGENT_ROLE, 1);
printf("snmp_subagent_main: 3\n");
  init_agent("smmapd_subagent");
printf("snmp_subagent_main: 4\n");
  init_dhsMIBObjects(); 
printf("snmp_subagent_main: 5\n");
  init_snmp("smmapd_subagent");
printf("snmp_subagent_main: 6\n");

  /* main loop here... */
  while(1) {
printf("snmp_subagent_main: main loop\n");
    res=agent_check_and_process(1);
printf("snmp_subagent_main: result in main loop: %d\n",res);
  }

  /* at shutdown time */
  snmp_shutdown("mysubagent");
}
#endif
